Home
last modified time | relevance | path

Searched defs:method (Results 1 – 25 of 152) sorted by relevance

1234567

/llvm-project-15.0.7/clang/test/SemaObjC/
H A DDoubleMethod.m8 - (void) method; // expected-note {{previous declaration is here}} method
9 - (void) method; // expected-warning {{multiple declarations of method 'method' found and ignored}} method
13 - (void) method {;} // expected-note {{previous declaration is here}} method
14 - (void) method {;} // expected-error {{duplicate declaration of method 'method'}} method
H A Dmethod-redecls-invalid-interface.m16 -(void) method; method
20 -(void) method { } method
H A Dcomptypes-5.m8 - (void) method; method
15 - (void) method; method in Addition
H A Dtypo-correction.m36 -(void)method; method
47 -(void)method { method
70 -(void)method { method
/llvm-project-15.0.7/clang/test/SemaObjCXX/
H A Divar-lookup.mm4 - (float*)method; method
10 - (int*)method; method
14 - (int*)method { method
H A Dmessage.mm6 - (int*)method; method
10 - (int*)method { method
22 - (int*)method; method
23 + (void)method; class
35 - (int*)method { method
43 + (void)method { class
50 + (int*)method; class
H A Ddllexport.mm25 - (void)method; method
29 - (void)method { method
H A Ddllimport.mm25 - (void)method; method
29 - (void)method { method
/llvm-project-15.0.7/clang/test/CXX/temp/temp.fct.spec/temp.arg.explicit/
H A Dp3-0x.cpp33 struct method { struct
34 vararg_func implementation;
36 method(vararg_func implementation) : implementation(implementation) {} in method() function
39 auto getImplementation() const -> TFunctionType in getImplementation()
/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Dmethod-target.cu10 void method() {} // dev-note {{'method' declared here}} in method() function
21 …void method(int) {} // expected-note {{candidate function not viable: call to __host__ function fr… in method() function
22 …void method(float) {} // expected-note {{candidate function not viable: call to __host__ function … in method() function
33 __device__ void method() {} // host-note {{'method' declared here}} in method() function
44 __device__ void method() {} // host-note {{'method' declared here}} in method() function
67 void method() {} // dev-note {{'method' declared here}}; in method() function
/llvm-project-15.0.7/clang/test/SemaCXX/Inputs/
H A Doverride-system-header.h5 #define STDMETHOD(method) virtual void method argument
6 #define IFACEMETHOD(method) STDMETHOD(method) argument
/llvm-project-15.0.7/llvm/docs/
H A DWritingAnLLVMPass.rst393 .. _writing-an-llvm-pass-CallGraphSCCPass:
441 .. _writing-an-llvm-pass-runOnSCC:
465 .. _writing-an-llvm-pass-FunctionPass:
515 .. _writing-an-llvm-pass-runOnFunction:
528 .. _writing-an-llvm-pass-doFinalization-mod:
542 .. _writing-an-llvm-pass-LoopPass:
578 .. _writing-an-llvm-pass-runOnLoop:
603 .. _writing-an-llvm-pass-RegionPass:
631 .. _writing-an-llvm-pass-runOnRegion:
701 .. _writing-an-llvm-pass-registration:
[all …]
/llvm-project-15.0.7/clang/test/Modules/
H A Dmethod_pool_transitive.m12 - (int)method; method
24 - (void)method; method
/llvm-project-15.0.7/clang/test/Analysis/
H A Dnullability-notes.m27 -(void) method; method
30 -(void) method { method
/llvm-project-15.0.7/clang/test/CodeGenObjC/
H A Dsynchronized.m6 - (void)method; method
13 {
H A Dprotocol-comdat.m4 - (void) method; method
14 - (void) method { } method
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Ddevice-vtable.cu56 void H::method() {} in method() function in H
59 void __device__ D::method() {} in method() function in D
/llvm-project-15.0.7/mlir/tools/mlir-tblgen/
H A DOpInterfacesGen.cpp42 static void emitMethodNameAndArgs(const InterfaceMethod &method, in emitMethodNameAndArgs()
169 for (auto &method : interface.getMethods()) { in emitInterfaceDef() local
207 for (auto &method : interface.getMethods()) { in emitConceptDecl() local
238 for (auto &method : interface.getMethods()) { in emitModelDecl() local
257 for (auto &method : interface.getMethods()) { in emitModelDecl() local
285 for (auto &method : interface.getMethods()) { in emitModelMethodsDef() local
319 for (auto &method : interface.getMethods()) { in emitModelMethodsDef() local
346 for (auto &method : interface.getMethods()) { in emitModelMethodsDef() local
393 for (auto &method : interface.getMethods()) { in emitTraitDecl() local
472 for (auto &method : interface.getMethods()) { in emitInterfaceDecl() local
[all …]
/llvm-project-15.0.7/clang/test/CodeGenCXX/
H A Doptnone-templates.cpp33 T method(T t, U u) in method() function in template_normal_base
42 __attribute__((optnone)) int method (int t, U u) in method() function in template_normal_base
70 __attribute__((optnone)) T method(T t, U u) in method() function in template_optnone_base
79 int method (int t, U u) in method() function in template_optnone_base
H A Dassume_attr.cpp81 __attribute__((assume("S<float>::method"))) void S<float>::method() {} in method() function in S
84 void S<int>::method() {} in method() function in S
/llvm-project-15.0.7/clang/test/CodeGenObjCXX/
H A Dmangle-blocks.mm23 - (void)method; method
27 - (void)method { method
/llvm-project-15.0.7/mlir/lib/Tools/lsp-server-support/
H A DTransport.h133 void method(llvm::StringLiteral method, ThisT *thisPtr, in method() function
146 void notification(llvm::StringLiteral method, ThisT *thisPtr, in notification()
159 OutgoingNotification<T> outgoingNotification(llvm::StringLiteral method) { in outgoingNotification()
H A DTransport.cpp42 StringRef method; member in __anon441a52320111::Reply
49 Reply::Reply(const llvm::json::Value &id, llvm::StringRef method, in Reply()
81 bool MessageHandler::onNotify(llvm::StringRef method, llvm::json::Value value) { in onNotify()
96 bool MessageHandler::onCall(llvm::StringRef method, llvm::json::Value params, in onCall()
163 void JSONTransport::notify(StringRef method, llvm::json::Value params) { in notify()
170 void JSONTransport::call(StringRef method, llvm::json::Value params, in call()
238 Optional<StringRef> method = object->getString("method"); in handleMessage() local
/llvm-project-15.0.7/lldb/test/API/commands/expression/context-object-objc/
H A Dmain.m13 -(int)method; method
32 -(int)method { method
/llvm-project-15.0.7/clang/test/FixIt/
H A Dtypo.m100 - (int)method; // expected-note{{using}} method
106 - (int)method; // expected-note{{also found}} method
110 - (int)method { method
135 - (void)method; // expected-note{{also found}} method
141 - (void)method { method

1234567